      SUBROUTINE MAP_STEEL_MSTART(T10,T20,W,W1,JTLOW,JTHIGH,MS,X1,JP)
C
      IMPLICIT NONE
      DOUBLE PRECISION DCTEMP(100), FTO(100)
      DOUBLE PRECISION AJ, AJ1, CONST, CORR, F, H, H1
      DOUBLE PRECISION KTEMP, MS, R, S, S1, SLOPE, T10, T20
      DOUBLE PRECISION W, W1, XTO, X1, XMS
C
      DOUBLE PRECISION MAP_STEEL_ENERGY, MAP_STEEL_FTO1
C
      INTEGER J, J1, J2, JP, JTLOW, JTHIGH
      INTEGER IL, ITLOW, ITHIGH, IT
C
C Initialize J1 and J2
C
      J1=0
      J2=0
C
C  Initialise FT0 and DCTEMP
C
       DO 22 IL     = 1,100
         FTO(IL)    = 0.0D+00
         DCTEMP(IL) = 0.0D+00
22     CONTINUE
C
C Guess a value of XTO, the carbon concentration (mole fraction) given by the
C   T-zero curve of the Temperature versus Carbon plot (phase diagram)
C
      XTO = 0.07D+00
C
C R is the universal gas constant
C
      R = 8.3143D+00
C
C H is the excess partial molar enthalpy of solution of carbon in austenite
C S is the excess partial molar entropy of solution of carbon in austenite
C H is in Joules per mole, S is in Joules per mole per K
C G. J. Shiflet, J. R. Bradley and H. I. Aaronson, Metallurgical Transactions
C   A, 9A (1978) 999.
C
        H = 38575.0D+00
        S = 13.48D+00
C
C This is to ensure that JTLOW, JTHIGH, JT are not changed on exit
C
       ITLOW  = JTLOW
       ITHIGH = JTHIGH
2       IT = (ITHIGH-ITLOW)/20
        IF(IT .LT. 5)THEN
           ITHIGH = 5*IT+ITLOW
           GOTO 2
        ENDIF

        IF(ITLOW .LT. 413)THEN
          ITLOW  = 413
          ITHIGH = 513
        ENDIF
C
C
C H1 is the excess partial molar enthalpy of solution of carbon in ferrite
C S1 is the excess partial molar entropy of solution of carbon in ferrite
C H1 is in Joules per mole, S1 is in Joules per mole per K
C J. A. Lobo and  G. H. Geiger, Metallurgical Transactions A 7A (1976),
C  pages 1347 and 1359.
C
      DO 1 J = ITLOW,ITHIGH,IT
C
          J1    = J1+1
          KTEMP = J
C
          IF (KTEMP .GE. 1000.0) THEN
              H1 = 105525.0D+00
              S1 = 45.34521D+00
          ELSE
              H1 = 111918.0D+00
              S1 = 51.44D+00
          ENDIF
C
C Calculate the free energy change for the transformation of austenite
C  to ferrite of the same chemical composition
C
          F   = MAP_STEEL_ENERGY(KTEMP,T10,T20)
          AJ  = 1.0D+00-DEXP(-W/(R*KTEMP))
          AJ1 = 1.0D+00-DEXP(-W1/(R*KTEMP))
          FTO(J1) = MAP_STEEL_FTO1(H,S,X1,KTEMP,W,W1,H1,S1,F,AJ,AJ1)
C
C Calculate the temperature in degrees centigrade
C
          DCTEMP(J1) = KTEMP-273.0D+00
C
1     CONTINUE
C
C Linear regression to obtain the free energy change for the transformation
C  of austenite to ferrite of the same chemical composition, as a
C  function of the temperature
C
      CALL MAP_UTIL_ANALY(J1,0,CONST,SLOPE,CORR,DCTEMP,FTO,JP)
C
C
C Calculate the martensite-start temperatures
C Modification made February 1991 to allow for large carbon concentrations
C Based on Metal Science paper on thermodynamics of martensitic transformations
C in plain carbon steels
C
C H. K. D. H. Bhadeshia, Metal Science 15 (1981) 175-177
C H. K. D. H. Bhadeshia, Metal Science 15 (1981) 178-180
C
      XMS = X1
      IF(XMS .GT. 0.0594D+00)  XMS = 0.0594D+00
      MS = (-1086.9D+00 + 2941.8D+00*XMS - 9.6016D+05*XMS*XMS
     &+ 2.5382D+07*XMS*XMS*XMS - 1.8488D+08*XMS*XMS*XMS*XMS
     & - CONST)/SLOPE
      IF(MS .le. -273.00)  MS = -273.15
C
        RETURN
        END

